@@ -1,4 +1,6 @@
 import os.path
+import pathlib
+import re
 import multiprocessing
 import shutil
 
@@ -104,7 +106,8 @@ class EmuConfig:
             raise Exception(f'The requested board {self.cfg.board_name} could not be found.')
 
 class VivadoConfig():
-    def __init__(self, parent: EmuConfig, vivado=None):
+    def __init__(self, parent: EmuConfig, vivado=None, version=None,
+                 version_year=None, version_number=None):
         # save reference to parent config
         self.parent = parent
 
@@ -128,6 +131,12 @@ class VivadoConfig():
                 self.lsf_opts_ls = "-eh_ram 70000 -eh_ncpu 8 -eh_dispatch LS_SHELL"
 
         self._vivado = vivado
+
+        # version, year, number
+        self._version = version
+        self._version_year = version_year
+        self._version_number = version_number
+
         # set various project options
         self.num_cores = multiprocessing.cpu_count()
         self.vio_name = 'vio_0'
@@ -142,6 +151,26 @@ class VivadoConfig():
             self._vivado = find_tool(name='vivado', hints=self.hints)
         return self._vivado
 
+    @property
+    def version(self):
+        if self._version is None:
+            self._version = pathlib.Path(self.vivado).parent.parent.name
+        return self._version
+
+    @property
+    def version_year(self):
+        if self._version_year is None:
+            self._version_year = re.match(r'(\d+)\.(\d+)', self.version).groups()[0]
+            self._version_year = int(self._version_year)
+        return self._version_year
+
+    @property
+    def version_number(self):
+        if self._version_number is None:
+            self._version_number = re.match(r'(\d+)\.(\d+)', self.version).groups()[1]
+            self._version_number = int(self._version_number)
+        return self._version_number
+
 class XceliumConfig():
     def __init__(self, parent: EmuConfig, xrun=None):
         # save reference to parent config
