@@ -104,17 +104,26 @@ class VivadoEmulation(VivadoTCLGenerator):
         self.writeln(f'launch_runs impl_1 -to_step write_bitstream -jobs {num_cores}')
         self.writeln('wait_on_run impl_1')
 
-        # re-generate the LTX file
-        # without this step, the ILA probes are sometimes split into individual bits
-        ltx_file_path = os.path.join(
+        # open the impl_1 run and determine its location
+        self.writeln('open_run impl_1')
+        impl_dir = os.path.join(
             self.target.project_root,
             f'{self.target.prj_cfg.vivado_config.project_name}.runs',
             'impl_1',
-            f'{self.target.cfg.top_module}.ltx'
         )
-        self.writeln('open_run impl_1')
+
+        # re-generate the LTX file
+        # without this step, the ILA probes are sometimes split into individual bits
+        ltx_file_path = os.path.join(impl_dir, f'{self.target.cfg.top_module}.ltx')
+        ltx_file_path = back2fwd(ltx_file_path)
         self.writeln(f'write_debug_probes -force {{{back2fwd(ltx_file_path)}}}')
 
+        # export the XSA if this is a more recent version of vivado
+        if self.version_year >= 2020:
+            xsa_file_path = os.path.join(impl_dir, f'{self.target.cfg.top_module}.xsa')
+            xsa_file_path = back2fwd(xsa_file_path)
+            self.writeln(f'write_hw_platform -fixed -include_bit -force -file {{{xsa_file_path}}}')
+
         # run bitstream generation
         self.run(filename=r"bitstream.tcl")
 
