@@ -2,14 +2,14 @@ class ConfigSections:
     """
     Container including enums for sections that can be used in config file.
     """
-    TARGET = "TARGET"
-    FPGA_BOARD = "FPGA_BOARD"
-    TOOL = "TOOL"
-    PLUGIN = "PLUGIN"
     PROJECT = "PROJECT"
+    CPU_TARGET = "CPU_TARGET"
+    FPGA_TARGET = "FPGA_TARGET"
+    PLUGIN = "PLUGIN"
     STRUCTURE = "STRUCTURE"
     FPGASIM = "FPGASIM"
 
+
 class BoardNames:
     """
     Container including enums for all supported boards.
@@ -28,6 +28,8 @@ class BoardNames:
     ZC702 = 'ZC702'
     ULTRA96 = 'ULTRA96'
     TE0720 = 'TE0720'
+    ARTY_200T_CUSTOM_LIDAR = 'ARTY_200T_CUSTOM_LIDAR'
+
 
 class PortDir:
     """
@@ -37,6 +39,19 @@ class PortDir:
     OUT = "output"
     INOUT = "inout"
 
+
+class TraceUnitOperators:
+    """
+    Container including enums for all valid operators that can be used for setting up the trace unit
+    """
+    EQUAL = 'eq'
+    NOTEQUAL = 'neq'
+    GREATER = 'gt'
+    GREATEREQUAL = 'gteq'
+    LESSER = 'lt'
+    LESSEREQUAL = 'lteq'
+
+
 class CtrlOps:
     """
     Container including enums for all supported control operations for controlling the FPGA.
@@ -44,9 +59,18 @@ class CtrlOps:
     WRITE_PARAMETER = 0
     READ_PARAMETER = 1
 
+
 class FPGASimCtrl:
     """
     Container including enums for all supported FPGA control interfaces.
     """
-    UART_ZYNQ = 'uart_zynq'
-    VIVADO_VIO = 'vivado_vio'
+    UART_ZYNQ = 'UART_ZYNQ'
+    VIVADO_VIO = 'VIVADO_VIO'
+
+
+class ResultFileTypes:
+    """
+    Container including enums for all supported data formats to store simulation/emulation results.
+    """
+    VCD = 'vcd'
+    CSV = 'csv'
\ No newline at end of file
