@@ -1,3 +1,4 @@
+import re
 from anasymod.sim.sim import Simulator
 from anasymod.generators.vivado import VivadoTCLGenerator
 
@@ -25,4 +26,4 @@ class VivadoSimulator(Simulator):
         v.writeln('launch_simulation')
 
         # run the simulation
-        v.run(filename='vivado_sim.tcl')
\ No newline at end of file
+        v.run(filename='vivado_sim.tcl', err_str=re.compile('^(Error|Fatal):'))
\ No newline at end of file
